@@ -1,10 +1,11 @@
 import threading, time
 
-def timer(time_length = False, message = "Timer Done!"):
-  try:
+def timer(time_length = False, message = False, variable = False):
+  try:  
     time_length = int(time_length)
   except:
     exit("FATAL ERROR: Expected intager with 'timer()''")
+  
   global completed_message
   global timer_length
   timer_length = time_length
@@ -13,7 +14,10 @@ def timer(time_length = False, message = "Timer Done!"):
     global timer_length
     global completed_message
     time.sleep(timer_length)
-    print(completed_message)
+    if completed_message:
+      print(completed_message)
+    if variable:
+      globals()[variable] = True  
   t = threading.Thread(target=sub_timer)
   t.start()
 def wait(time_length = False, message = False):
